@@ -5,8 +5,9 @@ import pickle
 from copy import copy
 from datetime import date, datetime
 from pathlib import Path, PurePath
-from typing import Any, ByteString, Callable, Mapping, Optional, Sequence, Type, TypeVar, Union
+from typing import Any, ByteString, Callable, Mapping, Optional, Sequence
 from typing import Tuple as Tup
+from typing import Type, TypeVar, Union
 
 import tomlkit
 
